pub fn record(entry: AuditEntry)Expand description
Record one permissioned request. Never panics and never fails a request — an audit that can break the wallet it observes is worse than no audit.
pub fn record(entry: AuditEntry)Record one permissioned request. Never panics and never fails a request — an audit that can break the wallet it observes is worse than no audit.