pub enum PostAnswer {
Accepted {
provider: String,
},
NotFinal {
provider: String,
said: String,
},
Refused {
said: String,
},
}Expand description
The broadcasters’ answer to one post, read as a hint.
Variants
Accepted
A broadcaster took it.
NotFinal
None took it and one called it not final: its lock time has not passed for the node behind that broadcaster. Transient.
Refused
None took it, for some other reason (or none answered).